@@ -72,14 +72,30 @@ class ManageWindow {
             }
         }));
         this._signalIDs.push(window.connect('notify::maximized-vertically', () => {
-            if (this._fixed && !window.maximized_vertically) {
-                window.maximize(Meta.MaximizeFlags.VERTICAL);
+            if (window.is_maximized) {
+                // Gnome Shell >= 49 API
+                if (this._fixed && !window.is_maximized()) {
+                    window.maximize();
+                }
+            } else {
+                // Gnome Shell < 49 API
+                if (this._fixed && !window.maximized_vertically) {
+                    window.maximize(Meta.MaximizeFlags.VERTICAL);
+                }
             }
             this._moveIntoPlace();
         }));
         this._signalIDs.push(window.connect('notify::maximized-horizontally', () => {
-            if (this._fixed && !window.maximized_horizontally) {
-                window.maximize(Meta.MaximizeFlags.HORIZONTAL);
+            if (window.is_maximized) {
+                // Gnome Shell >= 49 API
+                if (this._fixed && !window.is_maximized()) {
+                    window.maximize();
+                }
+            } else {
+                // Gnome Shell < 49 API
+                if (this._fixed && !window.maximized_horizontally) {
+                    window.maximize(Meta.MaximizeFlags.HORIZONTAL);
+                }
             }
             this._moveIntoPlace();
         }));
